==> crow-2.15.0.tar.bz2: crow-2.15.0/crow/crow_impl.h <==
/*
 *  Crow, a GUI designer for GTK+
 *  Copyright (c) 2005-2009 Maxim Udushlivy
 *
 *  Permission is hereby granted, free of charge, to any person
 *  obtaining a copy of this software and associated documentation
 *  files (the "Software"), to deal in the Software without
 *  restriction, including without limitation the rights to use, copy,
 *  modify, merge, publish, distribute, sublicense, and/or sell copies
 *  of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be
 *  included in all copies or substantial portions of the Software.
 *
 *  The software is provided "as is", without warranty of any kind,
 *  express or implied, including but not limited to the warranties of
 *  merchantability, fitness for a particular purpose and
 *  noninfringement. In no event shall the authors or copyright
 *  holders be liable for any claim, damages or other liability,
 *  whether in an action of contract, tort or otherwise, arising from,
 *  out of or in connection with the software or the use or other
 *  dealings in the software.
 */

#ifndef CROW_CROW_IMPL_H
#define CROW_CROW_IMPL_H

#include "crow.h"
#include "util.h"
#include <guiloader-c++.h>

#define CROW_DESIGNER_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), CROW_TYPE_DESIGNER, CrowDesignerPrivate))

typedef struct _CrowDesignerPrivate CrowDesignerPrivate;

struct _CrowDesignerPrivate {
	Crow::Designer * designer;
};

extern "C" {

void crow_designer_class_init(CrowDesignerClass * meta);
void crow_designer_init(CrowDesigner * obj);
void crow_designer_finalize(GObject * obj);
void crow_designer_emit_actions_updated(CrowActions changed, CrowDesigner * obj);
void crow_designer_emit_status_updated(const Glib::ustring & str, CrowDesigner * obj);
void crow_designer_emit_info_updated(const Glib::ustring & str, CrowDesigner * obj);
void crow_designer_emit_show_url(const Glib::ustring & str, CrowDesigner * obj);
void crow_designer_emit_modal_enter(CrowDesigner * obj);
void crow_designer_emit_modal_leave(CrowDesigner * obj);

}

namespace Crow {

class Designer : virtual public ObjectBase {

public:
	virtual void apply_settings(const Settings & settings) = 0;
	virtual void store_settings(Settings * settings) = 0;
	virtual void clear() = 0;
	virtual void load(const Glib::ustring & data) = 0;
	virtual Glib::ustring save() = 0;
	virtual Glib::ustring save_header() = 0;
	virtual void saved() = 0;
	virtual Gtk::Widget * get_widget() = 0;
	virtual CrowActions get_enabled_actions() = 0;
	virtual void run_action(CrowActions action) = 0;

	typedef sigc::signal<void, CrowActions> SignalActionsUpdated;
	typedef sigc::signal<void, Glib::ustring> SignalStatusUpdated;
	typedef sigc::signal<void, Glib::ustring> SignalInfoUpdated;
	typedef sigc::signal<void, Glib::ustring> SignalShowUrl;
	typedef sigc::signal<void> SignalModalEnter;
	typedef sigc::signal<void> SignalModalLeave;

	virtual sigc::connection connect_actions_updated(SignalActionsUpdated::slot_type) = 0;
	virtual sigc::connection connect_status_updated(SignalStatusUpdated::slot_type) = 0;
	virtual sigc::connection connect_info_updated(SignalInfoUpdated::slot_type) = 0;
	virtual sigc::connection connect_show_url(SignalShowUrl::slot_type) = 0;
	virtual sigc::connection connect_modal_enter(SignalModalEnter::slot_type) = 0;
	virtual sigc::connection connect_modal_leave(SignalModalLeave::slot_type) = 0;

};

class MainInit {

public:
	MainInit() { main= Gtk::Main::instance() ? NULL : new Main; }
	~MainInit() { delete main; }

private:

	class Main : public Gtk::Main { };

	Main * main;

};

class CrowInit {

friend class Crow::Object;
friend class Palette;

public:
	static CrowInit * get();

	static void enter(const std::string & msg);
	static void leave();

protected:
	static CrowInit * & ptr();

	CrowInit();
	~CrowInit();

	void init();

	void snapshot(const std::string & msg);
	void check();

	Palette * getPalette() { return palette; }

private:
	MainInit mainInit;
	Gui::Enter guiEnter;
	int refcounter;
	Palette * palette;

	#ifdef CROW_SANDBOX
		typedef std::set<Crow::Object *> Set;
		Set objects;
		std::list<Set> snapshots;
	#else
		int objects;
		std::list<int> snapshots;
	#endif

	std::list<std::string> labels;

	void objectCreated(Crow::Object * object);
	void objectDeleted(Crow::Object * object);

};

}

#endif

==> crow-2.17.1.tar.bz2: crow-2.17.1/crow/crow_impl.h <==
/*
 *  Crow, a GUI designer for GTK+
 *  Copyright (c) 2005-2010 Maxim Udushlivy
 *
 *  Permission is hereby granted, free of charge, to any person
 *  obtaining a copy of this software and associated documentation
 *  files (the "Software"), to deal in the Software without
 *  restriction, including without limitation the rights to use, copy,
 *  modify, merge, publish, distribute, sublicense, and/or sell copies
 *  of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be
 *  included in all copies or substantial portions of the Software.
 *
 *  The software is provided "as is", without warranty of any kind,
 *  express or implied, including but not limited to the warranties of
 *  merchantability, fitness for a particular purpose and
 *  noninfringement. In no event shall the authors or copyright
 *  holders be liable for any claim, damages or other liability,
 *  whether in an action of contract, tort or otherwise, arising from,
 *  out of or in connection with the software or the use or other
 *  dealings in the software.
 */

#ifndef CROW_CROW_IMPL_H
#define CROW_CROW_IMPL_H

#include "crow.h"
#include "util.h"

namespace Crow {

class CrowInit {

friend class Crow::Object;
friend class Palette;

public:
	static CrowInit * get();

	static void enter(string_cr msg);
	static void leave();

protected:
	static CrowInit * & ptr();

	CrowInit();
	~CrowInit();

	void init();

	void snapshot(string_cr msg);
	void check();

	Palette * getPalette() { return palette; }

private:
	Gui::Enter guiEnter;
	int refcounter;
	Palette * palette;

	#ifdef CROW_SANDBOX
		typedef std::set<Crow::Object *> Set;
		Set objects;
		std::list<Set> snapshots;
	#else
		int objects;
		std::list<int> snapshots;
	#endif

	std::list<std::string> labels;

	void objectCreated(Crow::Object * object);
	void objectDeleted(Crow::Object * object);

};

}

#endif
